==> ff-global-2.0.41.tgz: package/renderer/src/contactInfo/contact-info.ts <==
/*
 * 联系方式配置
 *
 * */

type L = {
  [key in f2.info.Type]?: f2.info.Config
}

let config: L = Object.freeze({
  email: {
    icon: 'info-email',
    color: 'rgb(62, 133, 246)',
    filter: /[^0-9a-zA-Z\-_@.()]/g,
    regular: /^ *[a-zA-Z0-9_\-.]+@[a-zA-Z0-9_\-]+(\.[a-zA-Z0-9_-]+)+$/,
    target: '_self',
    hrefPrefix: 'mailto:@url@'
  },
  phone: {
    icon: 'info-phone',
    color: 'rgb(246, 128, 44)',
    filter: /\D/g, //过滤正则，过滤掉不正确的格式
    regular: /^[0-9]{7,20}$/,
    target: '_self',
    hrefPrefix: 'javascript:;'
  },
  qq: {
    icon: 'info-qq',
    color: 'rgb(83,176,253)',
    filter: /[^0-9]/g,
    regular: /^\d{5,13}$/,
    hrefPrefix: 'tencent://message/?uin=@url@'
  },
  skype: {
    icon: 'info-skype',
    color: 'rgb(0,175,240)',
    regular: /^[\w._-]{3,}/,
    hrefPrefix: 'skype:@url@?userinfo'
  },
  telegram: {
    icon: 'info-telegram',
    color: 'rgb(0,175,240)',
    regular: /^[\w._-]{3,}/,
    hrefPrefix: 'skype:@url@?userinfo'
  },
  wechat: {
    icon: 'info-wechat',
    color: 'rgb(81,195,50)',
    regular: /^\S{3,}$/,
    hrefPrefix: 'javascript:;'
  },
  linkedin: {
    icon: 'info-linkedin',
    syncData: true,
    color: 'rgb(0,115,177)',
    filter: /(https?:\/\/)?([\w-]+\.)?linkedin.com\/in\/|\?.*/,
    regular: /^https?:\/\/www.linkedin.com\/in\/\S{2,}/,
    id: /\/(?:in|company)\/([^\/]*?)(\/|\?|\S{0}$)/i, //\/?|\/.*?
    hrefPrefix: '@url@',
    target: '_blank'
  },
  facebook: {
    icon: 'info-facebook',
    syncData: true,
    color: 'rgb(79,136,225)',
    filter: /(https?:\/\/)?([\w-]\.)?facebook.com\//,
    regular: /^https:\/\/([\w-]+).facebook.com\/\S+/,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  youtube: {
    icon: 'info-youtube',
    color: 'rgb(255,0,0)',
    filter: /(https?:\/\/)?([\w-]+\.)?youtube.com\/|\?.*/,
    regular: /^https:\/\/www.youtube.com\/\S+/,
    id: /www\.youtube\.com\/(?:(?:user|channel|c)\/)?([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  pinterest: {
    icon: 'info-pinterest',
    color: 'rgb(226,8,29)',
    filter: /(https?:\/\/)?([\w-]+\.)?pinterest.com\/|\?.*/,
    regular: /^https?:\/\/www.pinterest.com\/\S+/,
    id: /www\.pinterest\.com\/([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  instagram: {
    icon: 'info-instagram',
    color: 'rgb(224,8,31)',
    filter: /(https?:\/\/)?([\w-]+\.)?instagram.com\/|\?.*/,
    regular: /^https:\/\/www.instagram.com\/\S+/,
    id: /instagram\.com\/([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  twitter: {
    icon: 'info-twitter',
    syncData: true,
    color: 'rgb(29,161,242)',
    filter: /(https?:\/\/)?([\w-]+\.)?twitter.com\/|\?.*/,
    regular: /^https?:\/\/([\w-]+\.)?twitter\.com\/\S+/,
    id: /twitter\.com\/([^\/?]*?)([?&].*?|\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  wordpress: {
    //https://profiles.wordpress.org/takayukister/
    icon: 'info-wordpress',
    syncData: true,
    color: 'rgb(22,25,28)',
    filter: /(https?:\/\/)?([\w-]+\.)?profiles.wordpress.org\/|\?.*/,
    regular: /^https?:\/\/([\w-]+\.)?profiles\.wordpress\.org\/\S+/,
    id: /profiles\.wordpress\.org\/([^\/?]*?)([?&].*?|\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  crunchbase: {
    icon: 'info-cb',
    syncData: true,
    color: 'rgb(2,146,224)',

    filter: /(https?:\/\/)?([\w-]+\.)?crunchbase.com\/person\//,
    regular: /^https?:\/\/www.crunchbase.com\/person\/\S{2,}/,
    id: /\/person\/([^\/]*?)(\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  wiki: {
    icon: 'info-wiki',
    color: 'rgb(64, 158, 255)',

    filter: /(https?:\/\/)?([\w-]+\.)?wikipedia.org\/wiki\//,
    regular: /^https?:\/\/([\w-]+\.)?wikipedia.org\/wiki\/\S{2,}/,
    id: /wikipedia\.org\/wiki\/([^\/]*?)(\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  angellist: {
    icon: 'info-angelist',
    color: 'rgb(0, 0, 0)',
    filter: /(https?:\/\/)/,
    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  quora: {
    icon: 'info-quora',
    color: 'rgb(185, 43, 39)',
    filter: /(https?:\/\/)/,
    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  website: {
    icon: 'info-website',
    color: 'rgb(5,104,134)',

    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  github: {
    icon: 'info-github',
    color: 'rgb(36, 41, 46)',
    syncData: true,
    filter: /(https?:\/\/)?github.com\//,
    regular: /^https?:\/\/github.com\/\S+/,
    id: /^https:\/\/github.com\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  icq: {
    icon: 'info-icq',
    color: 'rgb(126,189,0)',
    filter: /[^0-9]/g,
    regular: /^\d{5,13}$/,
    id: /^(\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  whatsapp: {
    icon: 'info-whatsapp',
    color: 'rgb(58,195,76)',
    filter: void 0,
    regular: /^\+\d{5,15}$/,
    id: /^(\+\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  line: {
    icon: 'info-line',
    color: 'rgb(1,185,1)',
    filter: /[^0-9]/g,
    regular: /^\d{5,15}$/,
    id: /^(\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  tianyancha: {
    icon: 'info-tyc',
    color: 'rgb(0,128,225)',
    syncData: true,
    filter: /(https?:\/\/)?([\w-]+\.)?tianyancha.com\/human\/|\?.*/g,
    regular: /^https?:\/\/www.tianyancha.com\/human\/\S{2,}/,
    id: /\/human\/([^\/]+)/i, //https://www.tianyancha.com/human/1898977466-c146714008
    hrefPrefix: '@url@',
    target: '_blank'
  },
  qixin: {
    icon: 'info-qxb',
    color: 'rgb(253,208,0)',
    syncData: true,
    filter: /(https?:\/\/)?www.qixin.com\//,
    regular: /^https?:\/\/www.qixin.com\/(?:name-detail|shareholder)\/\S+$/i,
    id: /www.qixin.com\/((?:name-detail|shareholder)\/\S+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  qcc: {
    icon: 'info-qcc',
    color: 'rgb(0,128,225)',
    syncData: true,
    filter: /(https?:\/\/)?([\w-]+\.)?qcc.com\/pl\/|\?.*/g,
    regular: /^https?:\/\/www.qcc.com\/pl\/\S{2,}/,
    id: /\/((?:pl|product|firm)\/([^\/]+)$)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  weibo: {
    icon: 'info-sina',
    color: 'rgb(230,22,45)',
    filter: /(https?:\/\/)?([\w-]+\.)?weibo.com\/|[?#&].*/g,
    regular: /^https?:\/\/weibo.com\/[^?&\s]{2,}/,
    id: /\.com\/((u\/)?[^?#&\s/]{2,})/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  //知乎
  zhihu: {
    icon: 'info-zhihu',
    syncData: true,
    color: 'rgb(14,136,235)',

    filter: /(https?:\/\/)?www\.zhihu\.com\/people\//g,
    regular: /^https?:\/\/www\.zhihu\.com\/people\/[\w-]{2,}/,
    id: /zhihu\.com\/(people\/[\w-]{2,})/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  //it桔子
  itjuzi: {
    icon: 'info-itjuzi',
    syncData: true,
    color: 'rgb(255,137,102)',

    filter: /(https?:\/\/)?www\.itjuzi\.com\/person\//g,
    regular: /^https?:\/\/www\.itjuzi\.com\/person\/\d+/,
    id: /itjuzi\.com\/person\/(\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //清科数据投资界
  pedaily: {
    icon: 'info-tzj',
    syncData: true,
    color: 'rgb(18,150,219)',
    filter: /(https?:\/\/)?zdb\.pedaily\.cn\/people\/show/g,
    regular: /^https?:\/\/zdb\.pedaily\.cn\/people\/show\d+/,
    id: /pedaily\.cn\/people\/(show\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //创业帮
  cyzone: {
    icon: 'info-cyb',
    syncData: true,
    color: 'rgb(253,116,0)',
    filter: /^(https?:\/\/)?(www|data|bestla)\.cyzone\.cn\//g,
    regular: /^https?:\/\/(www|data|bestla)\.cyzone\.cn\/(investor\/[\w-]+\.html|author\/[\w-]+)/,
    id: /cyzone\.cn\/(?:\/saas)?\/?((?:investor|author)\/[\w-]+)(?:\.html)?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //创业帮
  wsj: {
    icon: 'info-wsj',
    syncData: true,
    color: 'rgb(19,19,19)',

    filter: /(https?:\/\/)?(www.)?wsj\.com\/market-data\/quotes\//g,
    regular: /^https?:\/\/www\.wsj\.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:\/[\w-]+){0,2}\/company-people\/executive-profile\/\d+)/,
    id: /wsj\.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:\/[\w-]+){0,2}\/company-people\/executive-profile\/\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  medium: {
    icon: 'info-medium',
    syncData: true,
    color: 'rgb(19,19,19)',
    regular: /^https?:\/\/([\w-]+\.)?medium\.com\/?(@[\w-]+)?[\/about]?/g,
    id: /https?:\/\/(?:[\w-]+\.)?medium\.com\/?(@?[\w-]+)$/,
    hrefPrefix: '@url@',
    target: '_blank'
  }
})

let ConfigArray: f2.info.Config[] = []
let menu: f2.info.Type[] = ['email', 'phone', 'qq', 'skype', 'wechat', 'linkedin', 'facebook', 'twitter', 'line', 'whatsapp', 'icq', 'telegram']
menu.forEach((key: f2.info.Type) => {
  let info = config[key]
  if (info) {
    ConfigArray.push({type: key, ...info})
  }
})
let ConfigArr = Object.freeze(ConfigArray)

export {ConfigArr}
export default config

==> ff-global-3.0.0.tgz: package/renderer/src/contactInfo/contact-info.ts <==
/*
 * 联系方式配置
 *
 * */

type L = {
  [key in f2.info.Type]?: f2.info.Config
}

let config: L = Object.freeze({
  email: {
    icon: 'info-email',
    color: 'rgb(62, 133, 246)',
    filter: /[^0-9a-zA-Z\-_@.()]/g,
    regular: /^ *[a-zA-Z0-9_\-.]+@[a-zA-Z0-9_\-]+(\.[a-zA-Z0-9_-]+)+$/,
    target: '_self',
    hrefPrefix: 'mailto:@url@'
  },
  phone: {
    icon: 'info-phone',
    color: 'rgb(246, 128, 44)',
    filter: /\D/g, //过滤正则，过滤掉不正确的格式
    regular: /^[0-9]{7,20}$/,
    target: '_self',
    hrefPrefix: 'javascript:;'
  },
  qq: {
    icon: 'info-qq',
    color: 'rgb(83,176,253)',
    filter: /[^0-9]/g,
    regular: /^\d{5,13}$/,
    hrefPrefix: 'tencent://message/?uin=@url@'
  },
  skype: {
    icon: 'info-skype',
    color: 'rgb(0,175,240)',
    regular: /^[\w._-]{3,}/,
    hrefPrefix: 'skype:@url@?userinfo'
  },
  telegram: {
    icon: 'info-telegram',
    color: 'rgb(0,175,240)',
    regular: /^[\w._-]{3,}/,
    hrefPrefix: 'skype:@url@?userinfo'
  },
  wechat: {
    icon: 'info-wechat',
    color: 'rgb(81,195,50)',
    regular: /^\S{3,}$/,
    hrefPrefix: 'javascript:;'
  },
  linkedin: {
    icon: 'info-linkedin',
    syncData: true,
    color: 'rgb(0,115,177)',
    filter: /(https?:\/\/)?([\w-]+\.)?linkedin.com\/in\/|\?.*/,
    regular: /^https?:\/\/www.linkedin.com\/in\/\S{2,}/,
    id: /\/(?:in|company)\/([^\/]*?)(\/|\?|\S{0}$)/i, //\/?|\/.*?
    hrefPrefix: '@url@',
    target: '_blank'
  },
  facebook: {
    icon: 'info-facebook',
    syncData: true,
    color: 'rgb(79,136,225)',
    filter: /(https?:\/\/)?([\w-]+\.)?facebook.com\//,
    regular: /^https:\/\/([\w-]+).facebook.com\/\S+/,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  youtube: {
    icon: 'info-youtube',
    color: 'rgb(255,0,0)',
    filter: /(https?:\/\/)?([\w-]+\.)?youtube.com\/|\?.*/,
    regular: /^https:\/\/www.youtube.com\/\S+/,
    id: /www\.youtube\.com\/(?:(?:user|channel|c)\/)?([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  pinterest: {
    icon: 'info-pinterest',
    color: 'rgb(226,8,29)',
    filter: /(https?:\/\/)?([\w-]+\.)?pinterest.com\/|\?.*/,
    regular: /^https?:\/\/www.pinterest.com\/\S+/,
    id: /www\.pinterest\.com\/([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  instagram: {
    icon: 'info-instagram',
    color: 'rgb(224,8,31)',
    filter: /(https?:\/\/)?([\w-]+\.)?instagram.com\/|\?.*/,
    regular: /^https:\/\/www.instagram.com\/\S+/,
    id: /instagram\.com\/([^\/]+)\/?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  twitter: {
    icon: 'info-twitter',
    syncData: true,
    color: 'rgb(29,161,242)',
    filter: /(https?:\/\/)?([\w-]+\.)?twitter.com\/|\?.*/,
    regular: /^https?:\/\/([\w-]+\.)?twitter\.com\/\S+/,
    id: /twitter\.com\/([^\/?]*?)([?&].*?|\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  wordpress: {
    //https://profiles.wordpress.org/takayukister/
    icon: 'info-wordpress',
    syncData: true,
    color: 'rgb(22,25,28)',
    filter: /(https?:\/\/)?([\w-]+\.)?profiles.wordpress.org\/|\?.*/,
    regular: /^https?:\/\/([\w-]+\.)?profiles\.wordpress\.org\/\S+/,
    id: /profiles\.wordpress\.org\/([^\/?]*?)([?&].*?|\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  crunchbase: {
    icon: 'info-cb',
    syncData: true,
    color: 'rgb(2,146,224)',

    filter: /(https?:\/\/)?([\w-]+\.)?crunchbase.com\/person\//,
    regular: /^https?:\/\/www.crunchbase.com\/person\/\S{2,}/,
    id: /\/person\/([^\/]*?)(\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  wiki: {
    icon: 'info-wiki',
    color: 'rgb(64, 158, 255)',
    filter: /https?:\/\//,
    regular: /^https?:\/\/([\w-]+\.)?wikipedia.org\/wiki\/\S{2,}/,
    id: /wikipedia\.org\/wiki\/([^\/]*?)(\/?|\/.*?)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  angellist: {
    icon: 'info-angelist',
    color: 'rgb(0, 0, 0)',
    filter: /(https?:\/\/)/,
    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  quora: {
    icon: 'info-quora',
    color: 'rgb(185, 43, 39)',
    filter: /(https?:\/\/)/,
    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  website: {
    icon: 'info-website',
    color: 'rgb(5,104,134)',

    regular: /^https?:\/\/\S+\.\S+/,
    id: /^https:\/\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  github: {
    icon: 'info-github',
    color: 'rgb(36, 41, 46)',
    syncData: true,
    filter: /(https?:\/\/)?github.com\//,
    regular: /^https?:\/\/github.com\/\S+/,
    id: /^https:\/\/github.com\/(.+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  icq: {
    icon: 'info-icq',
    color: 'rgb(126,189,0)',
    filter: /[^0-9]/g,
    regular: /^\d{5,13}$/,
    id: /^(\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  whatsapp: {
    icon: 'info-whatsapp',
    color: 'rgb(58,195,76)',
    filter: void 0,
    regular: /^\+\d{5,15}$/,
    id: /^(\+\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  line: {
    icon: 'info-line',
    color: 'rgb(1,185,1)',
    filter: /[^0-9]/g,
    regular: /^\d{5,15}$/,
    id: /^(\d+)$/i,
    hrefPrefix: 'javascript:;'
  },
  tianyancha: {
    icon: 'info-tyc',
    color: 'rgb(0,128,225)',
    syncData: true,
    filter: /(https?:\/\/)?([\w-]+\.)?tianyancha.com\/human\/|\?.*/g,
    regular: /^https?:\/\/www.tianyancha.com\/human\/\S{2,}/,
    id: /\/human\/([^\/]+)/i, //https://www.tianyancha.com/human/1898977466-c146714008
    hrefPrefix: '@url@',
    target: '_blank'
  },
  qixin: {
    icon: 'info-qxb',
    color: 'rgb(253,208,0)',
    syncData: true,
    filter: /(https?:\/\/)?www.qixin.com\//,
    regular: /^https?:\/\/www.qixin.com\/(?:name-detail|shareholder)\/\S+$/i,
    id: /www.qixin.com\/((?:name-detail|shareholder)\/\S+)$/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  qcc: {
    icon: 'info-qcc',
    color: 'rgb(0,128,225)',
    syncData: true,
    filter: /(https?:\/\/)?([\w-]+\.)?qcc.com\/pl\/|\?.*/g,
    regular: /^https?:\/\/www.qcc.com\/pl\/\S{2,}/,
    id: /\/((?:pl|product|firm)\/([^\/]+)$)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  weibo: {
    icon: 'info-sina',
    color: 'rgb(230,22,45)',
    filter: /(https?:\/\/)?([\w-]+\.)?weibo.com\/|[?#&].*/g,
    regular: /^https?:\/\/weibo.com\/[^?&\s]{2,}/,
    id: /\.com\/((u\/)?[^?#&\s/]{2,})/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  //知乎
  zhihu: {
    icon: 'info-zhihu',
    syncData: true,
    color: 'rgb(14,136,235)',

    filter: /(https?:\/\/)?www\.zhihu\.com\/people\//g,
    regular: /^https?:\/\/www\.zhihu\.com\/people\/[\w-]{2,}/,
    id: /zhihu\.com\/(people\/[\w-]{2,})/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  //it桔子
  itjuzi: {
    icon: 'info-itjuzi',
    syncData: true,
    color: 'rgb(255,137,102)',

    filter: /(https?:\/\/)?www\.itjuzi\.com\/person\//g,
    regular: /^https?:\/\/www\.itjuzi\.com\/person\/\d+/,
    id: /itjuzi\.com\/person\/(\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //清科数据投资界
  pedaily: {
    icon: 'info-tzj',
    syncData: true,
    color: 'rgb(18,150,219)',
    filter: /(https?:\/\/)?zdb\.pedaily\.cn\/people\/show/g,
    regular: /^https?:\/\/zdb\.pedaily\.cn\/people\/show\d+/,
    id: /pedaily\.cn\/people\/(show\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //创业帮
  cyzone: {
    icon: 'info-cyb',
    syncData: true,
    color: 'rgb(253,116,0)',
    filter: /^(https?:\/\/)?(www|data|bestla)\.cyzone\.cn\//g,
    regular: /^https?:\/\/(www|data|bestla)\.cyzone\.cn\/(investor\/[\w-]+\.html|author\/[\w-]+)/,
    id: /cyzone\.cn\/(?:\/saas)?\/?((?:investor|author)\/[\w-]+)(?:\.html)?/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },

  //创业帮
  wsj: {
    icon: 'info-wsj',
    syncData: true,
    color: 'rgb(19,19,19)',

    filter: /(https?:\/\/)?(www.)?wsj\.com\/market-data\/quotes\//g,
    regular: /^https?:\/\/www\.wsj\.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:\/[\w-]+){0,2}\/company-people\/executive-profile\/\d+)/,
    id: /wsj\.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:\/[\w-]+){0,2}\/company-people\/executive-profile\/\d+)/i,
    hrefPrefix: '@url@',
    target: '_blank'
  },
  medium: {
    icon: 'info-medium',
    syncData: true,
    color: 'rgb(19,19,19)',
    regular: /^https?:\/\/([\w-]+\.)?medium\.com\/?(@[\w-]+)?[\/about]?/g,
    id: /https?:\/\/(?:[\w-]+\.)?medium\.com\/?(@?[\w-]+)$/,
    hrefPrefix: '@url@',
    target: '_blank'
  }
})

let ConfigArray: f2.info.Config[] = []
let menu: f2.info.Type[] = ['email', 'phone', 'qq', 'skype', 'wechat', 'linkedin', 'facebook', 'twitter', 'line', 'whatsapp', 'icq', 'telegram']
menu.forEach((key: f2.info.Type) => {
  let info = config[key]
  if (info) {
    ConfigArray.push({type: key, ...info})
  }
})
let ConfigArr = Object.freeze(ConfigArray)

export {ConfigArr}
export default config
